@@ -12,12 +12,28 @@ from sklearn.model_selection import RandomizedSearchCV
 
 from lightgbm import early_stopping
 from lightgbm import log_evaluation
-
+import numpy as np
+from sklearn.metrics import f1_score
 #import general as g
 #import core_helper.model.general as g
 #import src.Prj_Core.core_helper.model.general as g
 from data_science_helper.model import general as g
 
+
+def lgb_f1_score(y_hat, data):
+    y_true = data.get_label()
+    y_hat = np.round(y_hat) # scikits f1 doesn't like probabilities
+    return 'f1', f1_score(y_true, y_hat), True
+
+
+def get_feval(score):     
+    if(score=="f1"):
+        feval=lgb_f1_score
+        
+    return feval
+
+
+
 def get_pipeline():
     '''
     lgb_pipe = pipeline.Pipeline([
@@ -100,9 +116,11 @@ def lgb_model_skl(X_train,y_train,X_test,y_test,metric='average_precision',param
     return model
 
 
-def lgb_model_train(X_train,y_train,X_test,y_test,params=None,num_rounds=None,early_stop=None,log=None):
+def lgb_model_train(X_train,y_train,X_test,y_test,params=None,metric='average_precision',num_rounds=None,early_stop=None,log=None):
 
     
+    feval = get_feval(metric)
+    
     if 'max_bin' in params:
         
         max_bin=params['max_bin']  
@@ -115,9 +133,9 @@ def lgb_model_train(X_train,y_train,X_test,y_test,params=None,num_rounds=None,ea
         d_valid = lgb.Dataset(X_test, label=y_test, categorical_feature=[])
         
 
+    
 
-
-    watchlist = [d_valid]
+    watchlist = [d_train,d_valid]
     
     print("--------------- lgb_model_train params -------------------")
     print(params)
@@ -125,7 +143,8 @@ def lgb_model_train(X_train,y_train,X_test,y_test,params=None,num_rounds=None,ea
     model = lgb.train(params,       
                   num_boost_round = num_rounds,
                   train_set=d_train,
-                  valid_names = ['data_valid'],
+                  valid_names = ['data_train','data_valid'],
+                  feval=feval,
                   valid_sets=watchlist,
                   callbacks=[log_evaluation(log),early_stopping(early_stop)]
                  )
